IntExtension extension

on

Properties

days → Duration

Available on int, provided by the IntExtension extension

Converts the integer to a Duration object representing that many days.
no setter
hours → Duration

Available on int, provided by the IntExtension extension

Converts the integer to a Duration object representing that many hours.
no setter
millis → Duration

Available on int, provided by the IntExtension extension

Converts the integer to a Duration object representing that many milliseconds.
no setter
minutes → Duration

Available on int, provided by the IntExtension extension

Converts the integer to a Duration object representing that many minutes.
no setter
seconds → Duration

Available on int, provided by the IntExtension extension

Converts the integer to a Duration object representing that many seconds.
no setter

Methods

rangeTo(int other, {bool inclusive = true}) → Iterable<int>

Available on int, provided by the IntExtension extension

Generates an iterable range of integers from this integer to other.